use serde::{Deserialize, Serialize};
use validator::Validate;

/// 微信用户登录，code通过wx.login获取
#[derive(Debug, Serialize, Deserialize, Validate)]
pub struct WxMinAppLogin {
    /// 微信code
    #[validate(
        required(message = "ValidateWxMinAppLoginCodeRequired"),
        length(min = 1, message = "ValidateWxMinAppLoginCodeRequired")
    )]
    pub code: Option<String>,
}

/// 微信用户登陆后的信息
///
/// 通过code登录后获取openid、session_key、unionid
#[derive(Debug, Serialize, Deserialize, Validate)]
pub struct WxLoginInfo {
    #[validate(
        required(message = "ValidateWxMinAppLoginInfoOpenidRequired"),
        length(min = 1, message = "ValidateWxMinAppLoginInfoOpenidRequired")
    )]
    pub openid: Option<String>,
    #[validate(
        required(message = "ValidateWxMinAppLoginSessionRequired"),
        length(min = 1, message = "ValidateWxMinAppLoginSessionRequired")
    )]
    pub session_key: Option<String>,
    pub unionid: Option<String>,
}
